#include <stdio.h>
#include <stdlib.h>
#include "CMutil.h"

typedef struct {
	float real;
	float imag;
	} CMC_complex;

typedef struct {
	double real;
	double imag;
	} CMC_double_complex;

shape ONED, TWOD;

float:ONED f_oned;
double:ONED d_oned;
CMC_complex:ONED c_oned;
CMC_double_complex:ONED z_oned;

float:TWOD f_twod;
double:TWOD d_twod;
CMC_complex:TWOD c_twod;
CMC_double_complex:TWOD z_twod;

main()
{
  int shapesize;

/* Create 32-member 1D shape */
  CM_make_vec_shape(&ONED, shapesize);
  printf("Allocated ONED shape\n");

/* Create 32 x 32-member 2D shape */
  CM_make_mat_shape(&TWOD, shapesize, shapesize);
  printf("Allocated TWOD shape\n");

/* Create the 1D parallel variables */
  CM_allocate_f_pvar(&f_oned, &ONED);
  CM_allocate_d_pvar(&d_oned, &ONED);
  CM_allocate_z_pvar(&z_oned, &ONED);
  CM_allocate_c_pvar(&c_oned, &ONED);
  printf("Allocated 1D parallel variables\n");

/* Create the 2D parallel variables */
  CM_allocate_f_pvar(&f_twod, &TWOD);
  CM_allocate_d_pvar(&d_twod, &TWOD);
  CM_allocate_z_pvar(&z_twod, &TWOD);
  CM_allocate_c_pvar(&c_twod, &TWOD);
  printf("Allocated 2D parallel variables\n");

  with (TWOD) {
        f_twod = 1.0;
	d_twod = (double) 1.0;
 	c_twod.real = 1.0;
	c_twod.imag = 0.0;
 	z_twod.real = (double) 1.0;
	z_twod.imag = 0.0;
        where (pcoord(0)==pcoord(1)) {
          f_twod = 3.0;
	  d_twod = (double)3.0;
	  c_twod.real = 3.0;
	  c_twod.imag = 2.5;
	  z_twod.real = 3.0;
	  z_twod.imag = 2.5;
	}
  }


/* Free the parallel variables */
  CM_free_pvar(&f_oned);
  CM_free_pvar(&d_oned);
  CM_free_pvar(&c_oned);
  CM_free_pvar(&z_oned);

  CM_free_pvar(&f_twod);
  CM_free_pvar(&d_twod);
  CM_free_pvar(&c_twod);
  CM_free_pvar(&z_twod);

/* Free the shapes */
}
